package
module
Version:
v0.0.0-...-acec4af
Opens a new window with list of versions in this module.
Published: Apr 1, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
func Get(name string) interface{}
取指定全局变量
func RegisterVariable(name string, data interface{}) interface{}
注册全局变量
Source Files
¶
Click to show internal directories.
Click to hide internal directories.