package
module
Version:
v0.0.0-...-a6a33e7
Opens a new window with list of versions in this module.
Published: May 6, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Isnull(val, def interface{}) interface{}
*
- 判断是否为空,val为nil时返回默认值
- @param val
- @param def
- @return
func Ternary(bl bool, trueVal, falseVal interface{}) interface{}
*
- 三元运算
- @param bl
- @param trueVal
- @param falseVal
- @return
Source Files
¶
Click to show internal directories.
Click to hide internal directories.