package
module
Version:
v0.0.0-...-317a764
Opens a new window with list of versions in this module.
Published: Feb 1, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
根据注册序列号创建注册码
registerSeries 注册序列号
func MD5(str ...interface{}) string
取MD5,大写
根据注册序列号判断注册码是否正确
registerSeries 注册序列号
key 注册码
Source Files
¶
Click to show internal directories.
Click to hide internal directories.